@@ -59,6 +59,7 @@ EDIT_FILETYPES = (
     (_("NSIS files"), ('.nsi', '.nsh')),
     (_("Web page files"), ('.css', '.htm', '.html',)),
     (_("XML files"), ('.xml',)),
+    (_("Javascript files"), ('.js',)),
     (_("Enaml files"), ('.enaml',)),
     (_("Configuration files"), ('.properties', '.session', '.ini', '.inf',
                                 '.reg', '.cfg', '.desktop')),
@@ -227,7 +228,9 @@ DEFAULTS = [
               'pyqt/ignore_sip_setapi_errors': False,
               'matplotlib/patch': True,
               'matplotlib/backend/enabled': True,
-              'matplotlib/backend/value': 'Qt4Agg',
+              'matplotlib/backend/value': 'MacOSX' if (sys.platform == 'darwin' \
+                                           and os.environ.get('QT_API') == 'pyside')\
+                                           else 'Qt4Agg',
               'umd/enabled': True,
               'umd/verbose': True,
               'umd/namelist': ['guidata', 'guiqwt'],
@@ -424,9 +427,9 @@ DEFAULTS = [
               }),
             ]
 
-DEV = not __file__.startswith(sys.prefix)
-DEV = False
-CONF = UserConfig('spyder', defaults=DEFAULTS, load=(not DEV), version='2.4.0',
+# XXX: Previously we had load=(not DEV) here but DEV was set to *False*.
+# Check if it *really* needs to be updated or not
+CONF = UserConfig('spyder', defaults=DEFAULTS, load=True, version='2.4.0',
                   subfolder=SUBFOLDER, backup=True, raw_mode=True)
 
 # Removing old .spyder.ini location:
