@@ -20,6 +20,7 @@ from code import InteractiveConsole
 # Local imports:
 from spyderlib.utils.dochelpers import isdefined
 from spyderlib.utils import encoding
+from spyderlib.utils.misc import remove_backslashes
 
 # Force Python to search modules in the current directory first:
 sys.path.insert(0, '')
@@ -173,7 +174,7 @@ has the same effect as typing a particular string at the help> prompt.
         # run command
         elif run_match:
             filename = guess_filename(run_match.groups()[0])
-            cmd = 'runfile(r"%s", args=None)' % filename
+            cmd = "runfile('%s', args=None)" % remove_backslashes(filename)
         # !cd system command
         elif cd_match:
             cmd = 'import os; os.chdir(r"%s")' % cd_match.groups()[0].strip()
