@@ -33,15 +33,6 @@ from spyderlib.qt.compat import (to_qvariant, from_qvariant,
                                  getexistingdirectory, getopenfilename)
 
 
-class SizeMixin(object):
-    """Mixin to keep widget size accessible
-    even when C++ object has been deleted"""
-    def resizeEvent(self, event):
-        """Reimplement Qt method"""
-        QDialog.resizeEvent(self, event)
-        self.emit(SIGNAL("size_change(QSize)"), self.size())
-
-
 class ConfigPage(QWidget):
     """Configuration page base class"""
     def __init__(self, parent, apply_callback=None):
@@ -95,11 +86,10 @@ class ConfigPage(QWidget):
         raise NotImplementedError
 
 
-class ConfigDialog(QDialog, SizeMixin):
+class ConfigDialog(QDialog):
     """Spyder configuration ('Preferences') dialog box"""
     def __init__(self, parent=None):
         QDialog.__init__(self, parent)
-        SizeMixin.__init__(self)
         
         # Destroying the C++ object right after closing the dialog box,
         # otherwise it may be garbage-collected in another QThread
@@ -203,6 +193,14 @@ class ConfigDialog(QDialog, SizeMixin):
         """This method is called to check all configuration page settings
         after configuration dialog has been shown"""
         self.emit(SIGNAL('check_settings()'))
+    
+    def resizeEvent(self, event):
+        """
+        Reimplement Qt method to be able to save the widget's size from the
+        main application
+        """
+        QDialog.resizeEvent(self, event)
+        self.emit(SIGNAL("size_change(QSize)"), self.size())
 
 
 class SpyderConfigPage(ConfigPage):
