@@ -14,7 +14,8 @@
 # Qt imports
 from spyderlib.qt.QtGui import (QVBoxLayout, QMessageBox, QInputDialog,
                                 QLineEdit, QPushButton, QGroupBox, QLabel,
-                                QTabWidget, QFontComboBox, QHBoxLayout)
+                                QTabWidget, QFontComboBox, QHBoxLayout,
+                                QButtonGroup)
 from spyderlib.qt.QtCore import SIGNAL, Qt
 from spyderlib.qt.compat import getopenfilename
 
@@ -26,19 +27,23 @@ import re
 import sys
 
 # Local imports
-from spyderlib.baseconfig import _, SCIENTIFIC_STARTUP, SUPPORTED_IPYTHON
+from spyderlib.baseconfig import _, SCIENTIFIC_STARTUP
+from spyderlib.ipythonconfig import SUPPORTED_IPYTHON
 from spyderlib.config import CONF
 from spyderlib.utils import programs
 from spyderlib.utils.misc import (get_error_match, get_python_executable,
-                                  remove_trailing_single_backslash,
-                                  is_python_script)
+                                  remove_backslashes, is_python_script)
 from spyderlib.utils.qthelpers import get_icon, create_action, mimedata2url
 from spyderlib.widgets.tabs import Tabs
 from spyderlib.widgets.externalshell.pythonshell import ExternalPythonShell
 from spyderlib.widgets.externalshell.systemshell import ExternalSystemShell
 from spyderlib.widgets.findreplace import FindReplace
 from spyderlib.plugins import SpyderPluginWidget, PluginConfigPage
+from spyderlib import dependencies
 
+MPL_REQVER = '>=1.0'
+dependencies.add("matplotlib", _("Interactive data plotting"),
+                 required_version=MPL_REQVER)
 
 def is_mpl_patch_available():
     """Return True if Matplotlib patch is available"""
@@ -49,20 +54,21 @@ def is_mpl_patch_available():
         return False
 
 
-def scientific_libs_available(interpreter):
-    """
-    Return True if numpy, scipy and matplotlib are installed in interpreter
-    """
-    mods = ['numpy', 'scipy', 'matplotlib']
-    check_mods = [programs.is_module_installed(m, interpreter=interpreter) \
-                  for m in mods]
-    return all(check_mods)
-
-
 class ExternalConsoleConfigPage(PluginConfigPage):
     def __init__(self, plugin, parent):
         PluginConfigPage.__init__(self, plugin, parent)
         self.get_name = lambda: _("Console")
+        self.def_startup_radio = None
+        self.cus_startup_radio = None
+        self.cus_exec_radio = None
+        self.pyexec_edit = None
+
+    def initialize(self):
+        PluginConfigPage.initialize(self)
+        self.connect(self.pyexec_edit, SIGNAL("textChanged(QString)"),
+                     self.python_executable_changed)
+        self.connect(self.cus_exec_radio, SIGNAL("toggled(bool)"),
+                     self.python_executable_switched)
 
     def setup_page(self):
         interface_group = QGroupBox(_("Interface"))
@@ -193,8 +199,17 @@ class ExternalConsoleConfigPage(PluginConfigPage):
         
         # Python executable Group
         pyexec_group = QGroupBox(_("Python executable"))
-        pyexec_label = QLabel(_("Path to Python interpreter "
-                                "executable binary:"))
+        pyexec_bg = QButtonGroup(pyexec_group)
+        pyexec_label = QLabel(_("Select the Python interpreter executable "
+                                "binary in which Spyder will run scripts:"))
+        def_exec_radio = self.create_radiobutton(
+                                _("Default (i.e. the same as Spyder's)"),
+                                'pythonexecutable/default', True,
+                                button_group=pyexec_bg)
+        self.cus_exec_radio = self.create_radiobutton(
+                                _("Use the following Python interpreter:"),
+                                'pythonexecutable/custom', False,
+                                button_group=pyexec_bg)
         if os.name == 'nt':
             filters = _("Executables")+" (*.exe)"
         else:
@@ -203,16 +218,15 @@ class ExternalConsoleConfigPage(PluginConfigPage):
                                              filters=filters)
         for le in self.lineedits:
             if self.lineedits[le][0] == 'pythonexecutable':
-                pyexec_edit = le
-        self.connect(pyexec_edit, SIGNAL("textChanged(QString)"),
-                     lambda pyexec: self.change_pystartup(pyexec,
-                                                          default_radio,
-                                                          custom_radio))
-        self.connect(pyexec_edit, SIGNAL("textChanged(QString)"),
-                     lambda pyexec: self.change_qtapi(pyexec))
-        
+                self.pyexec_edit = le
+        self.connect(def_exec_radio, SIGNAL("toggled(bool)"),
+                     pyexec_file.setDisabled)
+        self.connect(self.cus_exec_radio, SIGNAL("toggled(bool)"),
+                     pyexec_file.setEnabled)
         pyexec_layout = QVBoxLayout()
         pyexec_layout.addWidget(pyexec_label)
+        pyexec_layout.addWidget(def_exec_radio)
+        pyexec_layout.addWidget(self.cus_exec_radio)
         pyexec_layout.addWidget(pyexec_file)
         pyexec_group.setLayout(pyexec_layout)
         
@@ -227,28 +241,31 @@ class ExternalConsoleConfigPage(PluginConfigPage):
         
         # PYTHONSTARTUP replacement
         pystartup_group = QGroupBox(_("PYTHONSTARTUP replacement"))
+        pystartup_bg = QButtonGroup(pystartup_group)
         pystartup_label = QLabel(_("This option will override the "
                                    "PYTHONSTARTUP environment variable which\n"
                                    "defines the script to be executed during "
                                    "the Python interpreter startup."))
-        default_radio = self.create_radiobutton(
+        self.def_startup_radio = self.create_radiobutton(
                                         _("Default PYTHONSTARTUP script"),
-                                        'pythonstartup/default', True)
-        custom_radio = self.create_radiobutton(
+                                        'pythonstartup/default', True,
+                                        button_group=pystartup_bg)
+        self.cus_startup_radio = self.create_radiobutton(
                                         _("Use the following startup script:"),
-                                        'pythonstartup/custom', False)
+                                        'pythonstartup/custom', False,
+                                        button_group=pystartup_bg)
         pystartup_file = self.create_browsefile('', 'pythonstartup', '',
                                                 filters=_("Python scripts")+\
                                                 " (*.py)")
-        self.connect(default_radio, SIGNAL("toggled(bool)"),
+        self.connect(self.def_startup_radio, SIGNAL("toggled(bool)"),
                      pystartup_file.setDisabled)
-        self.connect(custom_radio, SIGNAL("toggled(bool)"),
+        self.connect(self.cus_startup_radio, SIGNAL("toggled(bool)"),
                      pystartup_file.setEnabled)
         
         pystartup_layout = QVBoxLayout()
         pystartup_layout.addWidget(pystartup_label)
-        pystartup_layout.addWidget(default_radio)
-        pystartup_layout.addWidget(custom_radio)
+        pystartup_layout.addWidget(self.def_startup_radio)
+        pystartup_layout.addWidget(self.cus_startup_radio)
         pystartup_layout.addWidget(pystartup_file)
         pystartup_group.setLayout(pystartup_layout)
         
@@ -282,7 +299,10 @@ class ExternalConsoleConfigPage(PluginConfigPage):
                          tip=_("This option will act on<br> "
                                "libraries such as Matplotlib, guidata "
                                "or ETS"))
-        interpreter = self.get_option('pythonexecutable')
+        if self.get_option('pythonexecutable/default', True):
+            interpreter = get_python_executable()
+        else:
+            interpreter = self.get_option('pythonexecutable')
         has_pyqt4 = programs.is_module_installed('PyQt4',
                                                  interpreter=interpreter)
         has_pyside = programs.is_module_installed('PySide',
@@ -411,40 +431,42 @@ class ExternalConsoleConfigPage(PluginConfigPage):
         vlayout = QVBoxLayout()
         vlayout.addWidget(tabs)
         self.setLayout(vlayout)
-    
-    def change_pystartup(self, pyexec, def_radio, custom_radio):
-        """
-        Automatically change to default PYTHONSTARTUP file if scientific libs
-        are not available
-        """
-        if not isinstance(pyexec, basestring):
-            pyexec = unicode(pyexec.toUtf8(), 'utf-8')
-        old_pyexec = self.get_option("pythonexecutable")
-        if not (pyexec == old_pyexec) and custom_radio.isChecked():
-            scientific = scientific_libs_available(pyexec)
-            if not scientific:
-                def_radio.setChecked(True)
-                custom_radio.setChecked(False)
 
-    def change_qtapi(self, pyexec):
-        """Automatically change qt_api setting after changing interpreter"""
+    def _auto_change_qt_api(self, pyexec):
+        """Change automatically Qt API depending on
+        selected Python executable"""
+        has_pyqt4 = programs.is_module_installed('PyQt4', interpreter=pyexec)
+        has_pyside = programs.is_module_installed('PySide', interpreter=pyexec)
+        for cb in self.comboboxes:
+            if self.comboboxes[cb][0] == 'qt/api':
+                qt_setapi_cb = cb
+        if has_pyside and not has_pyqt4:
+            qt_setapi_cb.setCurrentIndex(2)
+        elif has_pyqt4 and not has_pyside:
+            qt_setapi_cb.setCurrentIndex(1)
+        else:
+            qt_setapi_cb.setCurrentIndex(0)
+
+    def python_executable_changed(self, pyexec):
+        """Custom Python executable value has been changed"""
+        if not self.cus_exec_radio.isChecked():
+            return
         if not isinstance(pyexec, basestring):
             pyexec = unicode(pyexec.toUtf8(), 'utf-8')
-        old_pyexec = self.get_option("pythonexecutable")
-        if not (pyexec == old_pyexec):
-            has_pyqt4 = programs.is_module_installed('PyQt4',
-                                                     interpreter=pyexec)
-            has_pyside = programs.is_module_installed('PySide',
-                                                      interpreter=pyexec)
-            for cb in self.comboboxes:
-                if self.comboboxes[cb][0] == 'qt/api':
-                    qt_setapi_cb = cb
-            if has_pyside and not has_pyqt4:
-                qt_setapi_cb.setCurrentIndex(2)
-            elif has_pyqt4 and not has_pyside:
-                qt_setapi_cb.setCurrentIndex(1)
-            else:
-                qt_setapi_cb.setCurrentIndex(0)
+        old_pyexec = self.get_option("pythonexecutable",
+                                     get_python_executable())
+        if pyexec != old_pyexec:
+            self._auto_change_qt_api(pyexec)
+
+    def python_executable_switched(self, custom):
+        """Python executable default/custom radio button has been toggled"""
+        def_pyexec = get_python_executable()
+        cust_pyexec = self.pyexec_edit.text()
+        if not isinstance(cust_pyexec, basestring):
+            cust_pyexec = unicode(cust_pyexec.toUtf8(), 'utf-8')
+        if def_pyexec != cust_pyexec:
+            pyexec = cust_pyexec if custom else def_pyexec
+            self._auto_change_qt_api(pyexec)
 
 
 class ExternalConsole(SpyderPluginWidget):
@@ -471,18 +493,18 @@ class ExternalConsole(SpyderPluginWidget):
         except ImportError:
             self.set_option('pyqt/ignore_sip_setapi_errors', False)
         
+        # Python executable selection (initializing default values as well)
         executable = self.get_option('pythonexecutable',
                                      get_python_executable())
-        if self.get_option('pythonstartup/default', None) is None:
-            scientific = scientific_libs_available(executable)
-            self.set_option('pythonstartup/default', not scientific)
+        if self.get_option('pythonexecutable/default', True):
+            executable = get_python_executable()
+
+        # Python startup file selection
         if not osp.isfile(self.get_option('pythonstartup', '')):
-            scientific = scientific_libs_available(executable)
             self.set_option('pythonstartup', SCIENTIFIC_STARTUP)
-            self.set_option('pythonstartup/default', not scientific)
         # default/custom settings are mutually exclusive:
         self.set_option('pythonstartup/custom',
-                        not self.get_option('pythonstartup/default'))
+                        not self.get_option('pythonstartup/default', False))
         
         if not osp.isfile(executable):
             # This is absolutely necessary, in case the Python interpreter
@@ -659,9 +681,9 @@ class ExternalConsole(SpyderPluginWidget):
         
     def run_script_in_current_shell(self, filename, wdir, args, debug):
         """Run script in current shell, if any"""
-        line = "%s(r'%s'" % ('debugfile' if debug else 'runfile',
-                             unicode(filename))
-        norm = lambda text: remove_trailing_single_backslash(unicode(text))
+        norm = lambda text: remove_backslashes(unicode(text))
+        line = "%s('%s'" % ('debugfile' if debug else 'runfile',
+                            norm(filename))
         if args:
             line += ", args=r'%s'" % norm(args)
         if wdir:
@@ -764,8 +786,11 @@ class ExternalConsole(SpyderPluginWidget):
         light_background = self.get_option('light_background')
         show_elapsed_time = self.get_option('show_elapsed_time')
         if python:
-            pythonexecutable = self.get_option('pythonexecutable')
-            if self.get_option('pythonstartup/default', True):
+            if self.get_option('pythonexecutable/default', True):
+                pythonexecutable = get_python_executable()
+            else:
+                pythonexecutable = self.get_option('pythonexecutable')
+            if self.get_option('pythonstartup/default', True) or ipykernel:
                 pythonstartup = None
             else:
                 pythonstartup = self.get_option('pythonstartup', None)
@@ -791,6 +816,17 @@ class ExternalConsole(SpyderPluginWidget):
             umd_verbose = self.get_option('umd/verbose')
             ar_timeout = CONF.get('variable_explorer', 'autorefresh/timeout')
             ar_state = CONF.get('variable_explorer', 'autorefresh')
+
+            # CRUCIAL NOTE FOR IPYTHON KERNELS:
+            # autorefresh needs to be on so that our monitor
+            # can find __ipythonkernel__ in the globals namespace
+            # *after* the kernel has been started.
+            # Without the ns refresh provided by autorefresh, a
+            # client is *never* started (although the kernel is)
+            # Fix Issue 1595
+            if not ar_state and ipykernel:
+                ar_state = True
+
             if self.light_mode:
                 from spyderlib.plugins.variableexplorer import VariableExplorer
                 sa_settings = VariableExplorer.get_settings()
@@ -877,14 +913,44 @@ class ExternalConsole(SpyderPluginWidget):
                              self.open_file_in_spyder)
             if fname is None:
                 if ipykernel:
-                    tab_name = _("Kernel")
-                    tab_icon1 = get_icon('ipython_console.png')
-                    tab_icon2 = get_icon('ipython_console_t.png')
-                    if ipyclient:
-                        self.connect(shellwidget,
-                                 SIGNAL('create_ipython_client(QString)'),
-                                 lambda cf: self.create_ipyclient(
-                                         cf, kernel_widget=shellwidget))
+                    # Detect if kernel and frontend match or not
+                    if self.get_option('pythonexecutable/custom', False):
+                        frontend_ver = programs.get_module_version('IPython')
+                        if '0.13' in frontend_ver:
+                            frontend_ver = '<1.0'
+                        else:
+                            frontend_ver = '>=1.0'
+                        pyexec = self.get_option('pythonexecutable')
+                        kernel_and_frontend_match = \
+                          programs.is_module_installed('IPython',
+                                                       version=frontend_ver,
+                                                       interpreter=pyexec)
+                    else:
+                        kernel_and_frontend_match = True
+                    
+                    # Create a a kernel tab only if frontend and kernel
+                    # versions match
+                    if kernel_and_frontend_match:
+                        tab_name = _("Kernel")
+                        tab_icon1 = get_icon('ipython_console.png')
+                        tab_icon2 = get_icon('ipython_console_t.png')
+                        if ipyclient:
+                            self.connect(shellwidget,
+                                     SIGNAL('create_ipython_client(QString)'),
+                                     lambda cf: self.create_ipyclient(
+                                             cf, kernel_widget=shellwidget))
+                    else:
+                        QMessageBox.critical(self,
+                                     _("Mismatch between kernel and frontend"),
+                                     _("Your IPython frontend and kernel "
+                                       "versions are <b>incompatible!!</b>"
+                                       "<br><br>"
+                                       "We're sorry but we can't create an "
+                                       "IPython console for you."
+                                      ), QMessageBox.Ok)
+                        shellwidget.deleteLater()
+                        shellwidget = None
+                        return
                 else:
                     self.python_count += 1
                     tab_name = "Python %d" % self.python_count
