@@ -28,14 +28,17 @@ import time
 
 from IPython.config.loader import Config, load_pyconfig_files
 from IPython.core.application import get_ipython_dir
-from IPython.frontend.qt.kernelmanager import QtKernelManager
-from IPython.lib.kernel import find_connection_file
-
+from IPython.lib.kernel import find_connection_file, get_connection_info
+try:
+    from IPython.qt.manager import QtKernelManager # 1.0
+except ImportError:
+    from IPython.frontend.qt.kernelmanager import QtKernelManager # 0.13
+    
 # Local imports
+from spyderlib import dependencies
 from spyderlib.baseconfig import get_conf_path, _
 from spyderlib.utils import programs
-from spyderlib.utils.misc import (get_error_match,
-                                  remove_trailing_single_backslash)
+from spyderlib.utils.misc import get_error_match, remove_backslashes
 from spyderlib.utils.qthelpers import (get_icon, get_std_icon, create_action,
                                        create_toolbutton, add_actions)
 from spyderlib.widgets.tabs import Tabs
@@ -45,6 +48,11 @@ from spyderlib.plugins import SpyderPluginWidget, PluginConfigPage
 from spyderlib.widgets.mixins import SaveHistoryMixin
 
 
+SYMPY_REQVER = '>=0.7.0'
+dependencies.add("sympy", _("Symbolic mathematics for the IPython Console"),
+                 required_version=SYMPY_REQVER)
+
+
 class IPythonConsoleConfigPage(PluginConfigPage):
     def __init__(self, plugin, parent):
         PluginConfigPage.__init__(self, plugin, parent)
@@ -93,6 +101,17 @@ class IPythonConsoleConfigPage(PluginConfigPage):
         interface_layout.addWidget(inspector_box)
         interface_group.setLayout(interface_layout)
 
+        # Background Color Group
+        bg_group = QGroupBox(_("Background color"))
+        light_radio = self.create_radiobutton(_("Light background"),
+                                              'light_color', True)
+        dark_radio = self.create_radiobutton(_("Dark background"),
+                                             'dark_color', False)
+        bg_layout = QVBoxLayout()
+        bg_layout.addWidget(light_radio)
+        bg_layout.addWidget(dark_radio)
+        bg_group.setLayout(bg_layout)
+
         # Source Code Group
         source_code_group = QGroupBox(_("Source code"))
         buffer_spin = self.create_spinbox(
@@ -107,9 +126,10 @@ class IPythonConsoleConfigPage(PluginConfigPage):
         
         # --- Graphics ---
         # Pylab Group
-        pylab_group = QGroupBox(_("Support for graphics (Pylab)"))
+        pylab_group = QGroupBox(_("Support for graphics (Matplotlib)"))
         pylab_box = newcb(_("Activate support"), 'pylab')
-        autoload_pylab_box = newcb(_("Automatically load Pylab and NumPy"),
+        autoload_pylab_box = newcb(_("Automatically load Pylab and NumPy "
+                                     "modules"),
                                'pylab/autoload',
                                tip=_("This lets you load graphics support "
                                      "without importing \nthe commands to do "
@@ -186,11 +206,11 @@ class IPythonConsoleConfigPage(PluginConfigPage):
                                 "72"))
         width_spin = self.create_spinbox(
                           _("Width:")+"  ", " "+_("inches"),
-                          'pylab/inline/width', min_=4, max_=20, step=1,
+                          'pylab/inline/width', min_=2, max_=20, step=1,
                           tip=_("Default is 6"))
         height_spin = self.create_spinbox(
                           _("Height:")+"  ", " "+_("inches"),
-                          'pylab/inline/height', min_=4, max_=20, step=1,
+                          'pylab/inline/height', min_=1, max_=20, step=1,
                           tip=_("Default is 4"))
         
         inline_layout = QVBoxLayout()
@@ -345,7 +365,7 @@ class IPythonConsoleConfigPage(PluginConfigPage):
 
         # --- Tabs organization ---
         tabs = QTabWidget()
-        tabs.addTab(self.create_tab(font_group, interface_group, 
+        tabs.addTab(self.create_tab(font_group, interface_group, bg_group,
                                     source_code_group), _("Display"))
         tabs.addTab(self.create_tab(pylab_group, backend_group, inline_group),
                                     _("Graphics"))
@@ -565,8 +585,7 @@ class IPythonClient(QWidget, SaveHistoryMixin):
     def auto_refresh_namespacebrowser(self):
         """Refresh namespace browser"""
         if self.namespacebrowser:
-            if self.namespacebrowser.autorefresh:
-                self.namespacebrowser.refresh_table()
+            self.namespacebrowser.refresh_table()
     
     #------ Private API -------------------------------------------------------
     def _show_rich_help(self, text):
@@ -606,8 +625,12 @@ class IPythonClient(QWidget, SaveHistoryMixin):
     def closeEvent(self, event):
         """Reimplement Qt method to stop sending the custom_restart_kernel_died
         signal"""
-        self.ipywidget.custom_restart = False
-            
+        if programs.is_module_installed('IPython', '>=1.0'):
+            kc = self.ipywidget.kernel_client
+            kc.hb_channel.pause()
+        else:
+            self.ipywidget.custom_restart = False
+
 
 class IPythonConsole(SpyderPluginWidget):
     """
@@ -617,6 +640,7 @@ class IPythonConsole(SpyderPluginWidget):
     """
     CONF_SECTION = 'ipython_console'
     CONFIGWIDGET_CLASS = IPythonConsoleConfigPage
+    DISABLE_ACTIONS_WHEN_HIDDEN = False
 
     def __init__(self, parent):
         SpyderPluginWidget.__init__(self, parent)
@@ -690,17 +714,17 @@ class IPythonConsole(SpyderPluginWidget):
 
     def run_script_in_current_client(self, filename, wdir, args, debug):
         """Run script in current client, if any"""
-        norm = lambda text: remove_trailing_single_backslash(unicode(text))
+        norm = lambda text: remove_backslashes(unicode(text))
         client = self.get_current_client()
         if client is not None:
             # Internal kernels, use runfile
             if client.kernel_widget_id is not None:
-                line = "%s(r'%s'" % ('debugfile' if debug else 'runfile',
-                                     unicode(filename))
+                line = "%s('%s'" % ('debugfile' if debug else 'runfile',
+                                    norm(filename))
                 if args:
-                    line += ", args=r'%s'" % norm(args)
+                    line += ", args='%s'" % norm(args)
                 if wdir:
-                    line += ", wdir=r'%s'" % norm(wdir)
+                    line += ", wdir='%s'" % norm(wdir)
                 line += ")"
             else: # External kernels, use %run
                 line = "%run "
@@ -811,22 +835,47 @@ class IPythonConsole(SpyderPluginWidget):
         font = self.get_plugin_font()
         for client in self.clients:
             client.set_font(font)
+    
+    def kernel_and_frontend_match(self, connection_file):
+        # Determine kernel version
+        ci = get_connection_info(connection_file, unpack=True,
+                                 profile='default')
+        if ci.has_key(u'control_port'):
+            kernel_ver = '>=1.0'
+        else:
+            kernel_ver = '<1.0'
+        # is_module_installed checks if frontend version agrees with the
+        # kernel one
+        return programs.is_module_installed('IPython', version=kernel_ver)
 
-    def create_kernel_manager(self, connection_file=None):
-        """Create a kernel manager"""
+    def create_kernel_manager_and_client(self, connection_file=None):
+        """Create kernel manager and client"""
         cf = find_connection_file(connection_file, profile='default')
+        if not self.kernel_and_frontend_match(cf):
+            return None, None
         kernel_manager = QtKernelManager(connection_file=cf, config=None)
-        kernel_manager.load_connection_file()
-        kernel_manager.start_channels()
-        return kernel_manager
+        if programs.is_module_installed('IPython', '>=1.0'):
+            kernel_client = kernel_manager.client()
+            kernel_client.load_connection_file()
+            kernel_client.start_channels()
+            # To rely on kernel's heartbeat to know when a kernel has died
+            kernel_client.hb_channel.unpause()
+        else:
+            kernel_client = None
+            kernel_manager.load_connection_file()
+            kernel_manager.start_channels()
+        return kernel_manager, kernel_client
 
     def new_ipywidget(self, connection_file=None, config=None):
         """
         Create and return a new IPyhon widget from a connection file basename
         """
-        kernel_manager = self.create_kernel_manager(connection_file)
+        km, kc = self.create_kernel_manager_and_client(connection_file)
+        if (km, kc) == (None, None):
+            return None
         widget = SpyderIPythonWidget(config=config, local_kernel=False)
-        widget.kernel_manager = kernel_manager
+        widget.kernel_manager = km
+        widget.kernel_client = kc
         return widget
     
     #------ Public API --------------------------------------------------------
@@ -961,6 +1010,16 @@ class IPythonConsole(SpyderPluginWidget):
 
         ipywidget = self.new_ipywidget(connection_file,
                                                 config=self.ipywidget_config())
+        if ipywidget is None:
+            QMessageBox.critical(self,
+                                 _("Mismatch between kernel and frontend"),
+                                 _("Your IPython frontend and kernel versions "
+                                   "are <b>incompatible!!</b>"
+                                   "<br><br>"
+                                   "We're sorry but we can't create an IPython "
+                                   "console for you."
+                                ), QMessageBox.Ok)
+            return
 
         client = IPythonClient(self, connection_file, kernel_widget_id,
                                client_name, ipywidget,
@@ -1004,6 +1063,16 @@ class IPythonConsole(SpyderPluginWidget):
         # Connect to our variable explorer
         if kernel_widget is not None and self.variableexplorer is not None:
             nsb = self.variableexplorer.currentWidget()
+            # When the autorefresh button is active, our kernels
+            # start to consume more and more CPU during time
+            # Fix Issue 1450
+            # ----------------
+            # When autorefresh is off by default we need the next
+            # line so that kernels don't start to consume CPU
+            # Fix Issue 1595
+            nsb.auto_refresh_button.setChecked(True)
+            nsb.auto_refresh_button.setChecked(False)
+            nsb.auto_refresh_button.setEnabled(False)
             client.set_namespacebrowser(nsb)
         
         # Connect client to our history log
@@ -1015,17 +1084,17 @@ class IPythonConsole(SpyderPluginWidget):
         # Apply settings to newly created client widget:
         client.set_font( self.get_plugin_font() )
         
-        # Add tab and connect focus signals to client's control widgets
+        # Add tab and connect focus signal to client's control widget
         self.add_tab(client, name=client.get_name())
         self.connect(control, SIGNAL('focus_changed()'),
                      lambda: self.emit(SIGNAL('focus_changed()')))
-        self.connect(page_control, SIGNAL('focus_changed()'),
-                     lambda: self.emit(SIGNAL('focus_changed()')))
         
         # Update the find widget if focus changes between control and
         # page_control
         self.find_widget.set_editor(control)
         if page_control:
+            self.connect(page_control, SIGNAL('focus_changed()'),
+                         lambda: self.emit(SIGNAL('focus_changed()')))
             self.connect(control, SIGNAL('visibility_changed(bool)'),
                          self.refresh_plugin)
             self.connect(page_control, SIGNAL('visibility_changed(bool)'),
@@ -1160,8 +1229,9 @@ class IPythonConsole(SpyderPluginWidget):
         self.extconsole.set_ipykernel_attrs(connection_file, kernel_widget)
         
         # Connect client to new kernel
-        kernel_manager = self.create_kernel_manager(connection_file)        
-        client.ipywidget.kernel_manager = kernel_manager
+        km, kc = self.create_kernel_manager_and_client(connection_file)        
+        client.ipywidget.kernel_manager = km
+        client.ipywidget.kernel_client = kc
         client.kernel_widget_id = id(kernel_widget)
         client.get_control().setFocus()
         
