@@ -23,9 +23,10 @@ class ProjectExplorer(ProjectExplorerWidget, SpyderPluginMixin):
     
     def __init__(self, parent=None):
         ProjectExplorerWidget.__init__(self, parent=parent,
-                            name_filters=self.get_option('name_filters'),
-                            valid_types=VALID_EXT,
-                            show_all=self.get_option('show_all', False))
+                    name_filters=self.get_option('name_filters'),
+                    valid_types=VALID_EXT,
+                    show_all=self.get_option('show_all', False),
+                    show_hscrollbar=self.get_option('show_hscrollbar', True))
         SpyderPluginMixin.__init__(self, parent)
 
         # Initialize plugin
