@@ -11,7 +11,8 @@ from spyderlib.qt.QtCore import Signal
 
 # Local imports
 from spyderlib.baseconfig import _
-from spyderlib.config import CONF, get_icon
+from spyderlib.config import CONF
+from spyderlib.utils.qthelpers import get_icon
 from spyderlib.utils import programs
 from spyderlib.plugins import SpyderPluginMixin, PluginConfigPage
 from spyderlib.widgets.externalshell.monitor import REMOTE_SETTINGS
@@ -125,7 +126,7 @@ class VariableExplorer(QStackedWidget, SpyderPluginMixin):
         
     def remove_shellwidget(self, shellwidget_id):
         # If shellwidget_id is not in self.shellwidgets, it simply means
-        # that shell was not a Python/IPython-based console (it was a terminal)
+        # that shell was not a Python-based console (it was a terminal)
         if shellwidget_id in self.shellwidgets:
             nsb = self.shellwidgets.pop(shellwidget_id)
             self.removeWidget(nsb)
