@@ -16,17 +16,13 @@ from spyderlib.qt.QtGui import (QToolBar, QLabel, QGroupBox, QVBoxLayout,
 from spyderlib.qt.QtCore import SIGNAL, Signal
 from spyderlib.qt.compat import getexistingdirectory
 
-import os, sys
+import os
 import os.path as osp
 
-# For debugging purpose:
-STDOUT = sys.stdout
-
 # Local imports
 from spyderlib.utils import encoding
 from spyderlib.baseconfig import get_conf_path, _
-from spyderlib.config import get_icon
-from spyderlib.utils.qthelpers import get_std_icon, create_action
+from spyderlib.utils.qthelpers import get_icon, get_std_icon, create_action
 
 # Package local imports
 from spyderlib.widgets.comboboxes import PathComboBox
