@@ -15,7 +15,9 @@ from subprocess import Popen, PIPE
 import tempfile
 
 # Local import
+from spyderlib.baseconfig import _
 from spyderlib.utils import programs
+from spyderlib import dependencies
 
 
 #==============================================================================
@@ -68,12 +70,20 @@ def check_with_pyflakes(source_code, filename=None):
                                 warning.lineno))
         return results
 
-# Required version: Why 0.5.0? Because it's based on _ast (thread-safe)
-PYFLAKES_REQVER = '0.5.0'
+# Required versions
+# Why >=0.5.0? Because it's based on _ast (thread-safe)
+PYFLAKES_REQVER = '>=0.5.0'
+dependencies.add("pyflakes", _("Real-time code analysis on the Editor"),
+                 required_version=PYFLAKES_REQVER)
+
+PEP8_REQVER = '>=0.6'
+dependencies.add("pep8", _("Real-time code style analysis on the Editor"),
+                 required_version=PEP8_REQVER)
+
 
 def is_pyflakes_installed():
     """Return True if pyflakes required version is installed"""
-    return programs.is_module_installed('pyflakes', '>='+PYFLAKES_REQVER)
+    return programs.is_module_installed('pyflakes', PYFLAKES_REQVER)
 
 
 def get_checker_executable(name):
