@@ -13,9 +13,13 @@ Note: 'load' functions has to return a dictionary from which a globals()
 
 from __future__ import with_statement
 
-import sys, os, cPickle, tarfile, os.path as osp, shutil, warnings
-
-STDERR = sys.stderr
+import sys
+import os
+import cPickle
+import tarfile
+import os.path as osp
+import shutil
+import warnings
 
 
 try:
@@ -26,7 +30,7 @@ try:
             import scipy.io as spio
     except AttributeError:
         # Python 2.5: warnings.catch_warnings was introduced in Python 2.6
-        import scipy.io as spio
+        import scipy.io as spio  # analysis:ignore
     def load_matlab(filename):
         try:
             out = spio.loadmat(filename, struct_as_record=True,
@@ -54,7 +58,7 @@ except ImportError:
 
 
 try:
-    import numpy as np
+    import numpy as np  # analysis:ignore
     def load_array(filename):
         try:
             name = osp.splitext(osp.basename(filename))[0]
@@ -146,7 +150,8 @@ def save_dictionary(data, filename):
             if saved_arrays:
                 data['__saved_arrays__'] = saved_arrays
         pickle_filename = osp.splitext(filename)[0]+'.pickle'
-        cPickle.dump(data, file(pickle_filename, 'w'))
+        with open(pickle_filename, 'wb') as fdesc:
+            cPickle.dump(data, fdesc, 2)
         tar = tarfile.open(filename, "w")
         for fname in [pickle_filename]+[fn for fn in saved_arrays.itervalues()]:
             tar.add(osp.basename(fname))
@@ -170,7 +175,14 @@ def load_dictionary(filename):
         tar = tarfile.open(filename, "r")
         tar.extractall()
         pickle_filename = osp.splitext(filename)[0]+'.pickle'
-        data = cPickle.loads(file(pickle_filename, 'U').read())
+        try:
+            # Old format (Spyder 2.0-2.1 for Python 2)
+            with open(pickle_filename, 'U') as fdesc:
+                data = cPickle.loads(fdesc.read())
+        except cPickle.PickleError:
+            # New format (Spyder >=2.2 for Python 2 and Python 3)
+            with open(pickle_filename, 'rb') as fdesc:
+                data = cPickle.loads(fdesc.read())
         saved_arrays = {}
         if load_array is not None:
             # Loading numpy arrays saved with np.save
@@ -194,7 +206,7 @@ def load_dictionary(filename):
     return data, error_message
 
 
-from spyderlib.baseconfig import get_conf_path
+from spyderlib.baseconfig import get_conf_path, STDERR
 
 SAVED_CONFIG_FILES = ('.inspector', '.onlinehelp', '.path', '.pylint.results',
                       '.spyder.ini', '.temp.py', '.temp.spydata', 'template.py',
