@@ -2,7 +2,7 @@
 
 from spyderlib.qt.QtGui import (QLineEdit, QIcon, QHBoxLayout, QColor,
                                 QPushButton, QColorDialog, QPixmap)
-from spyderlib.qt.QtCore import SIGNAL, QSize, pyqtSignature, pyqtProperty
+from spyderlib.qt.QtCore import SIGNAL, QSize, Slot, Property
 
 
 class ColorButton(QPushButton):
@@ -19,16 +19,16 @@ class ColorButton(QPushButton):
         self._color = QColor()
     
     def choose_color(self):
-        rgba, valid = QColorDialog.getRgba(self._color.rgba(),
-                                           self.parentWidget())
-        if valid:
-            color = QColor.fromRgba(rgba)
+        color = QColorDialog.getColor(self._color, self.parentWidget(),
+                                      'Select Color',
+                                      QColorDialog.ShowAlphaChannel)
+        if color.isValid():
             self.set_color(color)
     
     def get_color(self):
         return self._color
     
-    @pyqtSignature("QColor")
+    @Slot(QColor)
     def set_color(self, color):
         if color != self._color:
             self._color = color
@@ -37,7 +37,7 @@ class ColorButton(QPushButton):
             pixmap.fill(color)
             self.setIcon(QIcon(pixmap))
     
-    color = pyqtProperty("QColor", get_color, set_color)
+    color = Property("QColor", get_color, set_color)
 
 
 def text_to_qcolor(text):
