@@ -16,7 +16,6 @@ Dictionary Editor Widget and Dialog based on Qt
 # pylint: disable=R0911
 # pylint: disable=R0201
 
-import os, sys, datetime
 from spyderlib.qt.QtGui import (QMessageBox, QTableView, QItemDelegate,
                                 QLineEdit, QVBoxLayout, QWidget, QColor,
                                 QDialog, QDateEdit, QDialogButtonBox, QMenu,
@@ -26,11 +25,16 @@ from spyderlib.qt.QtCore import (Qt, QModelIndex, QAbstractTableModel, SIGNAL,
                                  SLOT, QDateTime, Signal)
 from spyderlib.qt.compat import to_qvariant, from_qvariant, getsavefilename
 
+import os
+import sys
+import datetime
+
 # Local import
 from spyderlib.baseconfig import _
-from spyderlib.config import get_icon, get_font
+from spyderlib.guiconfig import get_font
 from spyderlib.utils.misc import fix_reference_name
-from spyderlib.utils.qthelpers import add_actions, create_action, qapplication
+from spyderlib.utils.qthelpers import (get_icon, add_actions, create_action,
+                                       qapplication)
 from spyderlib.widgets.dicteditorutils import (sort_against, get_size,
                get_human_readable_type, value_to_display, get_color_name,
                is_known_type, FakeObject, Image, ndarray, array, MaskedArray,
@@ -1258,6 +1262,13 @@ class RemoteDictEditorTableView(BaseTableView):
         """Toggle remote editing state"""
         self.sig_option_changed.emit('remote_editing', state)
         self.remote_editing_enabled = state
+
+    def oedit_possible(self, key):
+        if (self.is_list(key) or self.is_dict(key) 
+            or self.is_array(key) or self.is_image(key)):
+            # If this is a remote dict editor, the following avoid 
+            # transfering large amount of data through the socket
+            return True
             
     def edit_item(self):
         """
@@ -1272,9 +1283,8 @@ class RemoteDictEditorTableView(BaseTableView):
             if not index.isValid():
                 return
             key = self.model.get_key(index)
-            if (self.is_list(key) or self.is_dict(key) 
-                or self.is_array(key) or self.is_image(key)):
-                # If this is a remote dict editor, the following avoid 
+            if self.oedit_possible(key):
+                # If this is a remote dict editor, the following avoid
                 # transfering large amount of data through the socket
                 self.oedit(key)
             else:
