@@ -16,9 +16,8 @@ from spyderlib.qt.compat import from_qvariant
 
 # Local import
 from spyderlib.baseconfig import _, STDOUT
-from spyderlib.config import get_icon
-from spyderlib.utils.qthelpers import (create_action, create_toolbutton,
-                                       set_item_user_text)
+from spyderlib.utils.qthelpers import (get_icon, create_action,
+                                       create_toolbutton, set_item_user_text)
 from spyderlib.widgets.onecolumntree import OneColumnTree
 
 
@@ -410,12 +409,6 @@ class OutlineExplorerTreeWidget(OneColumnTree):
             editor_id = self.editor_ids[self.current_editor]
             self.root_item_selected(self.editor_items[editor_id])
 
-    def clicked(self, item):
-        """Click event"""
-        if isinstance(item, FileRootItem):
-            self.root_item_selected(item)
-        self.activated(item)
-
     def get_root_item(self, item):
         root_item = item
         while isinstance(root_item.parent(), QTreeWidgetItem):
@@ -429,8 +422,11 @@ class OutlineExplorerTreeWidget(OneColumnTree):
             line = item.line
         root_item = self.get_root_item(item)
         self.freeze = True
-        self.parent().emit(SIGNAL("edit_goto(QString,int,QString)"),
-                           root_item.path, line, item.text(0))
+        if line:
+            self.parent().emit(SIGNAL("edit_goto(QString,int,QString)"),
+                               root_item.path, line, item.text(0))
+        else:
+            self.parent().emit(SIGNAL("edit(QString)"), root_item.path)
         self.freeze = False
         parent = self.current_editor.parent()
         for editor_id, i_item in self.editor_items.iteritems():
@@ -441,14 +437,21 @@ class OutlineExplorerTreeWidget(OneColumnTree):
                         self.current_editor = editor
                         break
                 break
-    
-    
+
+    def clicked(self, item):
+        """Click event"""
+        if isinstance(item, FileRootItem):
+            self.root_item_selected(item)
+        self.activated(item)
+
+
 class OutlineExplorerWidget(QWidget):
     """
     Class browser
     
     Signals:
         SIGNAL("edit_goto(QString,int,QString)")
+        SIGNAL("edit(QString)")
     """
     def __init__(self, parent=None, show_fullpath=True, fullpath_sorting=True,
                  show_all_files=True, show_comments=True):
