@@ -1,13 +1,13 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright © 2009 Pierre Raybaut
+# Copyright © 2009-2010 Pierre Raybaut
 # Licensed under the terms of the MIT License
 # (see spyderlib/__init__.py for details)
 
 """Module that provides a GUI-based editor for matplotlib's figure options"""
 
 from spyderlib.widgets.formlayout import fedit
-from spyderlib.config import get_icon
+from spyderlib.utils.qthelpers import get_icon
 
 import matplotlib.cm, matplotlib.image
 from matplotlib.colors import rgb2hex, is_color_like
