@@ -24,37 +24,22 @@ import re
 import fnmatch
 import os.path as osp
 from subprocess import Popen, PIPE
+import traceback
 
 # Local imports
-from spyderlib.utils import programs
+from spyderlib.utils.vcs import is_hg_installed, get_vcs_root
 from spyderlib.utils.misc import abspardir, get_common_path
-from spyderlib.utils.qthelpers import (get_std_icon, create_toolbutton,
-                                       get_filetype_icon)
+from spyderlib.utils.qthelpers import (get_icon, get_std_icon,
+                                       create_toolbutton, get_filetype_icon)
 from spyderlib.baseconfig import _
-from spyderlib.config import get_icon
 from spyderlib.widgets.comboboxes import PathComboBox, PatternComboBox
 from spyderlib.widgets.onecolumntree import OneColumnTree
 
 
-def is_hg_installed():
-    """Return True if Mercurial is installed"""
-    return programs.find_program('hg') is not None
-
-def get_hg_root(path):
-    """Return Mercurial root directory path"""
-    previous_path = path
-    while not osp.isdir(osp.join(path, '.hg')):
-        path = abspardir(path)
-        if path == previous_path:
-            return
-        else:
-            previous_path = path
-    return osp.abspath(path)
-
 #def find_files_in_hg_manifest(rootpath, include, exclude):
 #    p = Popen("hg manifest", stdout=PIPE)
 #    found = []
-#    hgroot = get_hg_root(rootpath)
+#    hgroot = get_vcs_root(rootpath)
 #    for path in p.stdout.read().splitlines():
 #        dirname = osp.join('.', osp.dirname(path))
 #        if re.search(exclude, dirname+os.sep):
@@ -87,7 +72,7 @@ def get_hg_root(path):
 #    nb = 0
 #    for fname in filenames:
 #        for lineno, line in enumerate(file(fname)):
-#            for text in texts:
+#            for text, enc in texts:
 #                if regexp:
 #                    found = re.search(text, line)
 #                    if found is not None:
@@ -96,16 +81,20 @@ def get_hg_root(path):
 #                    found = line.find(text)
 #                    if found > -1:
 #                        break
+#                    try:
+#                        line_dec = line.decode(enc)
+#                    except UnicodeDecodeError:
+#                        line_dec = line
 #            if regexp:
 #                for match in re.finditer(text, line):
 #                    res = results.get(osp.abspath(fname), [])
-#                    res.append((lineno+1, match.start(), line))
+#                    res.append((lineno+1, match.start(), line_dec))
 #                    results[osp.abspath(fname)] = res
 #                    nb += 1
 #            else:
 #                while found > -1:
 #                    res = results.get(osp.abspath(fname), [])
-#                    res.append((lineno+1, found, line))
+#                    res.append((lineno+1, found, line_dec))
 #                    results[osp.abspath(fname)] = res
 #                    for text in texts:
 #                        found = line.find(text, found+1)
@@ -147,15 +136,22 @@ class SearchThread(QThread):
         self.completed = False
         
     def run(self):
-        self.filenames = []
-        if self.hg_manifest:
-            ok = self.find_files_in_hg_manifest()
-        elif self.python_path:
-            ok = self.find_files_in_python_path()
-        else:
-            ok = self.find_files_in_path(self.rootpath)
-        if ok:
-            self.find_string_in_files()
+        try:
+            self.filenames = []
+            if self.hg_manifest:
+                ok = self.find_files_in_hg_manifest()
+            elif self.python_path:
+                ok = self.find_files_in_python_path()
+            else:
+                ok = self.find_files_in_path(self.rootpath)
+            if ok:
+                self.find_string_in_files()
+        except Exception:
+            # Important note: we have to handle unexpected exceptions by 
+            # ourselves because they won't be catched by the main thread
+            # (known QThread limitation/bug)
+            traceback.print_exc()
+            self.error_flag = _("Unexpected error: see internal console")
         self.stop()
         self.emit(SIGNAL("finished(bool)"), self.completed)
         
@@ -191,7 +187,7 @@ class SearchThread(QThread):
     def find_files_in_hg_manifest(self):
         p = Popen(['hg', 'manifest'], stdout=PIPE,
                   cwd=self.rootpath, shell=True)
-        hgroot = get_hg_root(self.rootpath)
+        hgroot = get_vcs_root(self.rootpath)
         self.pathlist = [hgroot]
         for path in p.stdout.read().splitlines():
             with QMutexLocker(self.mutex):
@@ -244,8 +240,8 @@ class SearchThread(QThread):
                 if self.stopped:
                     return
             try:
-                for lineno, line in enumerate(file(fname)):
-                    for text in self.texts:
+                for lineno, line in enumerate(open(fname)):
+                    for text, enc in self.texts:
                         if self.text_re:
                             found = re.search(text, line)
                             if found is not None:
@@ -254,18 +250,22 @@ class SearchThread(QThread):
                             found = line.find(text)
                             if found > -1:
                                 break
+                    try:
+                        line_dec = line.decode(enc)
+                    except UnicodeDecodeError:
+                        line_dec = line
                     if self.text_re:
                         for match in re.finditer(text, line):
                             res = self.results.get(osp.abspath(fname), [])
-                            res.append((lineno+1, match.start(), line))
+                            res.append((lineno+1, match.start(), line_dec))
                             self.results[osp.abspath(fname)] = res
                             self.nb += 1
                     else:
                         while found > -1:
                             res = self.results.get(osp.abspath(fname), [])
-                            res.append((lineno+1, found, line))
+                            res.append((lineno+1, found, line_dec))
                             self.results[osp.abspath(fname)] = res
-                            for text in self.texts:
+                            for text, enc in self.texts:
                                 found = line.find(text, found+1)
                                 if found > -1:
                                     break
@@ -436,7 +436,7 @@ class FindOptions(QWidget):
     def detect_hg_repository(self, path=None):
         if path is None:
             path = os.getcwdu()
-        hg_repository = is_hg_installed() and get_hg_root(path) is not None
+        hg_repository = is_hg_installed() and get_vcs_root(path) is not None
         self.hg_manifest.setEnabled(hg_repository)
         if not hg_repository and self.hg_manifest.isChecked():
             self.custom_dir.setChecked(True)
@@ -453,12 +453,12 @@ class FindOptions(QWidget):
         if not utext:
             return
         try:
-            texts = [str(utext)]
+            texts = [(utext.encode('ascii'), 'ascii')]
         except UnicodeEncodeError:
             texts = []
-            for encoding in self.supported_encodings:
+            for enc in self.supported_encodings:
                 try:
-                    texts.append( utext.encode(encoding) )
+                    texts.append((utext.encode(enc), enc))
                 except UnicodeDecodeError:
                     pass
         text_re = self.edit_regexp.isChecked()
@@ -536,12 +536,17 @@ class ResultsBrowser(OneColumnTree):
         self.set_title('')
         self.root_items = None
         
-    def activated(self):
+    def activated(self, item):
+        """Double-click event"""
         itemdata = self.data.get(self.currentItem())
         if itemdata is not None:
             filename, lineno = itemdata
             self.parent().emit(SIGNAL("edit_goto(QString,int,QString)"),
                                filename, lineno, self.search_text)
+
+    def clicked(self, item):
+        """Click event"""
+        self.activated(item)
         
     def set_results(self, search_text, results, pathlist, nb,
                     error_flag, completed):
