@@ -72,6 +72,8 @@ import datetime
 # Local imports
 from spyderlib.baseconfig import _, DEBUG, STDERR
 
+DEBUG_FORMLAYOUT = DEBUG >= 2
+
 
 class ColorButton(QPushButton):
     """
@@ -238,7 +240,7 @@ class FormWidget(QWidget):
         if comment:
             self.formlayout.addRow(QLabel(comment))
             self.formlayout.addRow(QLabel(" "))
-        if DEBUG:
+        if DEBUG_FORMLAYOUT:
             print("\n"+("*"*80))
             print("DATA:", self.data)
             print("*"*80)
@@ -254,7 +256,7 @@ class FormWidget(QWidget):
 
     def setup(self):
         for label, value in self.data:
-            if DEBUG:
+            if DEBUG_FORMLAYOUT:
                 print("value:", value)
             if label is None and value is None:
                 # Separator: (None, None)
