@@ -22,8 +22,7 @@ from functools import partial as ft_partial
 
 # Local import
 from spyderlib.baseconfig import _
-from spyderlib.config import get_icon
-from spyderlib.utils.qthelpers import add_actions, create_action
+from spyderlib.utils.qthelpers import get_icon, add_actions, create_action
 
 def try_to_parse(value):
     _types = ('int', 'float')
@@ -48,7 +47,7 @@ class FakeObject(object):
 try:
     from numpy import ndarray, array
 except ImportError:
-    class ndarray(FakeObject):
+    class ndarray(FakeObject):  # analysis:ignore
         """Fake ndarray"""
         pass
 
@@ -57,10 +56,9 @@ import datetime
 try:
     from dateutil.parser import parse as dateparse
 except ImportError:
-    from string import atoi
-    def dateparse(datestr, dayfirst=True):
+    def dateparse(datestr, dayfirst=True):  # analysis:ignore
         """Just for 'day/month/year' strings"""
-        _a, _b, _c = map(atoi, datestr.split('/'))
+        _a, _b, _c = map(int, datestr.split('/'))
         if dayfirst:
             return datetime.datetime(_c, _b, _a)
         return datetime.datetime(_c, _a, _b)
@@ -589,7 +587,7 @@ class ImportWizard(QDialog):
 def test(text):
     """Test"""
     from spyderlib.utils.qthelpers import qapplication
-    _app = qapplication()
+    _app = qapplication()  # analysis:ignore
     dialog = ImportWizard(None, text)
     if dialog.exec_():
         print dialog.get_data()
