@@ -18,16 +18,16 @@ import __builtin__
 from spyderlib.widgets.objecteditor import oedit
 __builtin__.oedit = oedit
 
-import sys
 import os
 import threading
 from time import time
 from subprocess import Popen
 
 from spyderlib.qt.QtGui import QMessageBox
-from spyderlib.qt.QtCore import SIGNAL, QObject
+from spyderlib.qt.QtCore import SIGNAL, QObject, QEventLoop
 
 # Local import
+from spyderlib import get_versions
 from spyderlib.utils.qthelpers import create_action, get_std_icon
 from spyderlib.interpreter import Interpreter
 from spyderlib.utils.dochelpers import getargtxt, getsource, getdoc, getobjdir
@@ -35,17 +35,17 @@ from spyderlib.utils.misc import get_error_match
 #TODO: remove the CONF object and make it work anyway
 # In fact, this 'CONF' object has nothing to do in package spyderlib.widgets
 # which should not contain anything directly related to Spyder's main app
-from spyderlib.baseconfig import get_conf_path, _
+from spyderlib.baseconfig import get_conf_path, _, DEBUG
 from spyderlib.config import CONF
 from spyderlib.widgets.shell import PythonShellWidget
 
 
-def create_banner(moreinfo, message=''):
-    """Create shell banner"""
-    if message:
-        message = '\n' + message + '\n'
-    return 'Python %s on %s\n' % (sys.version, sys.platform) + \
-            moreinfo+'\n' + message + '\n'
+def create_banner(message):
+    """Create internal shell banner"""
+    versions = get_versions()
+    return 'Spyder %s internal shell on Python %s %dbits [%s]\n%s'\
+           % (versions['spyder'], versions['python'], versions['bitness'],
+              versions['system'], message)
 
 
 class SysOutput(QObject):
@@ -68,10 +68,15 @@ class SysOutput(QObject):
         self.lock.release()
         return s
 
+class WidgetProxyData(object):
+    pass
+
 class WidgetProxy(QObject):
     """Handle Shell widget refresh signal"""
-    def __init__(self):
+    def __init__(self, input_condition):
         QObject.__init__(self)
+        self.input_data = None
+        self.input_condition = input_condition
         
     def new_prompt(self, prompt):
         self.emit(SIGNAL("new_prompt(QString)"), prompt)
@@ -81,16 +86,30 @@ class WidgetProxy(QObject):
         
     def edit(self, filename, external_editor=False):
         self.emit(SIGNAL("edit(QString,bool)"), filename, external_editor)
+    
+    def data_available(self):
+        """Return True if input data is available"""
+        return self.input_data is not WidgetProxyData
+    
+    def wait_input(self, prompt=''):
+        self.input_data = WidgetProxyData
+        self.emit(SIGNAL("wait_input(QString)"), prompt)
+    
+    def end_input(self, cmd):
+        self.input_condition.acquire()
+        self.input_data = cmd
+        self.input_condition.notify()
+        self.input_condition.release()
 
 
 class InternalShell(PythonShellWidget):
     """Shell base widget: link between PythonShellWidget and Interpreter"""
     def __init__(self, parent=None, namespace=None, commands=[], message="",
-                 max_line_count=300, font=None, debug=False, exitfunc=None,
-                 profile=False, multithreaded=True, light_background=True):
+                 max_line_count=300, font=None, exitfunc=None, profile=False,
+                 multithreaded=True, light_background=True):
         PythonShellWidget.__init__(self, parent,
                                    get_conf_path('.history_internal.py'),
-                                   debug, profile)
+                                   profile)
         
         self.set_light_background(light_background)
         
@@ -101,6 +120,10 @@ class InternalShell(PythonShellWidget):
         if font is not None:
             self.set_font(font)
         
+        # Allow raw_input support:
+        self.input_loop = None
+        self.input_mode = False
+        
         # KeyboardInterrupt support
         self.interrupted = False # used only for not-multithreaded mode
         self.connect(self, SIGNAL("keyboard_interrupt()"),
@@ -141,7 +164,7 @@ class InternalShell(PythonShellWidget):
         if self.interpreter is not None:
             self.interpreter.closing()
         self.interpreter = Interpreter(namespace, self.exitfunc,
-                                       SysOutput, WidgetProxy, self.debug)
+                                       SysOutput, WidgetProxy, DEBUG)
         self.connect(self.interpreter.stdout_write,
                      SIGNAL("void data_avail()"), self.stdout_avail)
         self.connect(self.interpreter.stderr_write,
@@ -152,11 +175,13 @@ class InternalShell(PythonShellWidget):
                      SIGNAL("new_prompt(QString)"), self.new_prompt)
         self.connect(self.interpreter.widget_proxy,
                      SIGNAL("edit(QString,bool)"), self.edit_script)
+        self.connect(self.interpreter.widget_proxy,
+                     SIGNAL("wait_input(QString)"), self.wait_input)
         if self.multithreaded:
             self.interpreter.start()
         
-        # interpreter banner
-        banner = create_banner(_('Type "copyright", "credits" or "license" for more information.'), self.message)
+        # Interpreter banner
+        banner = create_banner(self.message)
         self.write(banner, prompt=True)
 
         # Initial commands
@@ -195,6 +220,23 @@ class InternalShell(PythonShellWidget):
         if data:
             self.write(data, error=True)
             self.flush(error=True)
+    
+    
+    #------Raw input support
+    def wait_input(self, prompt=''):
+        """Wait for input (raw_input support)"""
+        self.new_prompt(prompt)
+        self.setFocus()
+        self.input_mode = True
+        self.input_loop = QEventLoop()
+        self.input_loop.exec_()
+        self.input_loop = None
+    
+    def end_input(self, cmd):
+        """End of wait_input mode"""
+        self.input_mode = False
+        self.input_loop.exit()
+        self.interpreter.widget_proxy.end_input(cmd)
 
 
     #----- Menus, actions, ...
@@ -331,6 +373,9 @@ class InternalShell(PythonShellWidget):
         Execute a command
         cmd: one-line command only, with '\n' at the end
         """
+        if self.input_mode:
+            self.end_input(cmd)
+            return
         if cmd.endswith('\n'):
             cmd = cmd[:-1]
         # cls command
@@ -346,7 +391,7 @@ class InternalShell(PythonShellWidget):
         else:
             if history:
                 self.add_to_history(cmd)
-        self.interpreter.stdin_write.write(cmd + '\n')
+        self.interpreter.stdin_write.write(cmd.encode("utf-8") + '\n')
         if not self.multithreaded:
             self.interpreter.run_line()
             self.emit(SIGNAL("refresh()"))
