@@ -9,7 +9,10 @@ IPython v0.13+ client's widget
 """
 
 # IPython imports
-from IPython.frontend.qt.console.rich_ipython_widget import RichIPythonWidget
+try:  # 1.0
+    from IPython.qt.console.rich_ipython_widget import RichIPythonWidget
+except ImportError: # 0.13
+    from IPython.frontend.qt.console.rich_ipython_widget import RichIPythonWidget
 
 # Qt imports
 from spyderlib.qt.QtGui import QTextEdit, QKeySequence, QShortcut
@@ -18,6 +21,7 @@ from spyderlib.utils.qthelpers import restore_keyevent
 
 # Local imports
 from spyderlib.config import CONF
+from spyderlib.utils import programs
 from spyderlib.widgets.mixins import (BaseEditMixin, InspectObjectMixin,
                                       TracebackLinksMixin)
 
@@ -121,6 +125,7 @@ class SpyderIPythonWidget(RichIPythonWidget):
         self.custom_control = IPythonControlWidget
         self.custom_page_control = IPythonPageControlWidget
         super(SpyderIPythonWidget, self).__init__(*args, **kw)
+        self.set_background_color()
         
         # --- Spyder variables ---
         self.ipyclient = None
@@ -153,25 +158,32 @@ class SpyderIPythonWidget(RichIPythonWidget):
         banner = default_gui_banner
         
         pylab_o = CONF.get('ipython_console', 'pylab', True)
-        if pylab_o:
+        autoload_pylab_o = CONF.get('ipython_console', 'pylab/autoload', True)
+        mpl_installed = programs.is_module_installed('matplotlib')
+        if mpl_installed and (pylab_o and autoload_pylab_o):
             backend_o = CONF.get('ipython_console', 'pylab/backend', 0)
             backends = {0: 'module://IPython.zmq.pylab.backend_inline',
                         1: 'Qt4Agg', 2: 'Qt4Agg', 3: 'MacOSX', 4: 'GTKAgg',
                         5: 'WXAgg', 6: 'TKAgg'}
-            pylab_message = """
+            pylab_013_message = """
 Welcome to pylab, a matplotlib-based Python environment [backend: %s].
 For more information, type 'help(pylab)'.\n""" % backends[backend_o]
-            banner = banner + pylab_message
+            pylab_1_message = """
+Populating the interactive namespace from numpy and matplotlib"""
+            if programs.is_module_installed('IPython', '>=1.0'):
+                banner = banner + pylab_1_message
+            else:
+                banner = banner + pylab_013_message
         
         sympy_o = CONF.get('ipython_console', 'symbolic_math', True)
         if sympy_o:
             lines = """
 These commands were executed:
-from __future__ import division
-from sympy import *
-x, y, z, t = symbols('x y z t')
-k, m, n = symbols('k m n', integer=True)
-f, g, h = symbols('f g h', cls=Function)
+>>> from __future__ import division
+>>> from sympy import *
+>>> x, y, z, t = symbols('x y z t')
+>>> k, m, n = symbols('k m n', integer=True)
+>>> f, g, h = symbols('f g h', cls=Function)
 """
             banner = banner + lines
         return banner
@@ -185,7 +197,15 @@ f, g, h = symbols('f g h', cls=Function)
         but only if the kernel is currently looking for raw input.
         """
         if self._reading:
-            self.kernel_manager.stdin_channel.input(line)
+            if programs.is_module_installed('IPython', '>=1.0'):
+                self.kernel_client.stdin_channel.input(line)
+            else:
+                self.kernel_manager.stdin_channel.input(line)
+    
+    def set_background_color(self):
+        lightbg_o = CONF.get('ipython_console', 'light_color', True)
+        if not lightbg_o:
+            self.set_default_style(colors='linux')
 
     #---- IPython private methods ---------------------------------------------
     def _context_menu_make(self, pos):
