@@ -177,49 +177,6 @@ class BaseEditMixin(object):
         """
         self.__move_cursor_anchor(what, direction, QTextCursor.KeepAnchor)
 
-    def select_current_block(self):
-        """
-        Select block under cursor
-        Block = group of lines separated by either empty lines or commentaries
-        """
-        cursor = self.textCursor()
-        def _is_separator(cursor):
-            cursor0 = QTextCursor(cursor)
-            cursor0.select(QTextCursor.BlockUnderCursor)
-            text = unicode(cursor0.selectedText())
-            return len(text.strip()) == 0 or text.lstrip()[0] == '#'
-        cursor.movePosition(QTextCursor.StartOfBlock)
-        cur_pos = prev_pos = cursor.position()
-        while _is_separator(cursor):
-            # Moving to the next code block
-            cursor.movePosition(QTextCursor.NextBlock)
-            prev_pos = cur_pos
-            cur_pos = cursor.position()
-            if cur_pos == prev_pos:
-                return
-        while not _is_separator(cursor):
-            # Moving to the previous code block
-            cursor.movePosition(QTextCursor.PreviousBlock)
-            prev_pos = cur_pos
-            cur_pos = cursor.position()
-            if cur_pos == prev_pos:
-                if _is_separator(cursor):
-                    return
-                else:
-                    break
-        cursor.setPosition(prev_pos)
-        while not _is_separator(cursor):
-            # Moving to the next code block
-            cursor.movePosition(QTextCursor.NextBlock,
-                                QTextCursor.KeepAnchor)
-            cur_pos = cursor.position()
-            if cur_pos == prev_pos:
-                cursor.movePosition(QTextCursor.EndOfBlock,
-                                    QTextCursor.KeepAnchor)
-                break
-            prev_pos = cur_pos
-        self.setTextCursor(cursor)
-
 
     #------Text: get, set, ...
     def __select_text(self, position_from, position_to):
