@@ -14,15 +14,13 @@ from spyderlib.qt.QtGui import (QDialog, QListWidget, QDialogButtonBox,
 from spyderlib.qt.QtCore import Qt, SIGNAL, SLOT
 from spyderlib.qt.compat import getexistingdirectory
 
-import os, sys, os.path as osp
-
-# For debugging purpose:
-STDOUT = sys.stdout
+import os
+import sys
+import os.path as osp
 
 # Local imports
-from spyderlib.utils.qthelpers import get_std_icon, create_toolbutton
+from spyderlib.utils.qthelpers import get_icon, get_std_icon, create_toolbutton
 from spyderlib.baseconfig import _
-from spyderlib.config import get_icon
 
 
 class PathManager(QDialog):
@@ -239,7 +237,7 @@ class PathManager(QDialog):
 def test():
     """Run path manager test"""
     from spyderlib.utils.qthelpers import qapplication
-    _app = qapplication()
+    _app = qapplication()  # analysis:ignore
     test = PathManager(None, sys.path[:-10], sys.path[-10:])
     test.exec_()
     print test.get_path_list()
