@@ -465,9 +465,11 @@ class ShellBaseWidget(ConsoleBaseWidget, SaveHistoryMixin):
     def _key_ctrl_space(self):
         raise NotImplementedError
     def _key_home(self, shift, ctrl):
-        raise NotImplementedError
+        if self.is_cursor_on_last_line():
+            self.stdkey_home(shift, ctrl, self.current_prompt_pos)
     def _key_end(self, shift, ctrl):
-        raise NotImplementedError
+        if self.is_cursor_on_last_line():
+            self.stdkey_end(shift, ctrl)
     def _key_pageup(self):
         raise NotImplementedError
     def _key_pagedown(self):
@@ -752,16 +754,6 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget,
         if not self.is_completion_widget_visible():
             self.show_code_completion(automatic=False)
                 
-    def _key_home(self, shift, ctrl):
-        """Action for Home key"""
-        if self.is_cursor_on_last_line():
-            self.stdkey_home(shift, ctrl, self.current_prompt_pos)
-                
-    def _key_end(self, shift, ctrl):
-        """Action for End key"""
-        if self.is_cursor_on_last_line():
-            self.stdkey_end(shift, ctrl)
-                
     def _key_pageup(self):
         """Action for PageUp key"""
         pass
@@ -924,9 +916,11 @@ class PythonShellWidget(TracebackLinksMixin, ShellBaseWidget,
         # Looking for ' or ": filename completion
         q_pos = max([text.rfind("'"), text.rfind('"')])
         if q_pos != -1:
-            self.show_completion_list(self.get_cdlistdir(),
-                                      completion_text=text[q_pos+1:],
-                                      automatic=automatic)
+            completions = self.get_cdlistdir()
+            if completions:
+                self.show_completion_list(completions,
+                                          completion_text=text[q_pos+1:],
+                                          automatic=automatic)
             return
             
     #------ Drag'n Drop
