@@ -14,8 +14,7 @@ from spyderlib.qt.QtCore import SIGNAL, Qt
 # Local imports
 from spyderlib.baseconfig import get_translation
 _ = get_translation("p_profiler", dirname="spyderplugins")
-from spyderlib.config import get_icon
-from spyderlib.utils.qthelpers import create_action
+from spyderlib.utils.qthelpers import get_icon, create_action
 from spyderlib.plugins import SpyderPluginMixin, PluginConfigPage, runconfig
 
 from spyderplugins.widgets.profilergui import (ProfilerWidget,
@@ -79,7 +78,12 @@ class Profiler(ProfilerWidget, SpyderPluginMixin):
     def get_plugin_actions(self):
         """Return a list of actions related to plugin"""
         return []
-    
+
+    def on_first_registration(self):
+        """Action to be performed on first plugin registration"""
+        self.main.tabify_plugins(self.main.inspector, self)
+        self.dockwidget.hide()
+
     def register_plugin(self):
         """Register plugin in Spyder's main window"""
         self.connect(self, SIGNAL("edit_goto(QString,int,QString)"),
@@ -97,7 +101,7 @@ class Profiler(ProfilerWidget, SpyderPluginMixin):
         
         self.main.run_menu_actions += [profiler_act]
         self.main.editor.pythonfile_dependent_actions += [profiler_act]
-                    
+
     def refresh_plugin(self):
         """Refresh profiler widget"""
         #self.remove_obsolete_items()  # FIXME: not implemented yet
