@@ -14,16 +14,10 @@
 from spyderlib.qt.QtGui import QInputDialog, QVBoxLayout, QGroupBox, QLabel
 from spyderlib.qt.QtCore import SIGNAL, Qt
 
-import sys
-
-# For debugging purpose:
-STDOUT = sys.stdout
-
 # Local imports
 from spyderlib.baseconfig import get_translation
 _ = get_translation("p_pylint", dirname="spyderplugins")
-from spyderlib.config import get_icon
-from spyderlib.utils.qthelpers import create_action
+from spyderlib.utils.qthelpers import get_icon, create_action
 from spyderlib.plugins import SpyderPluginMixin, PluginConfigPage
 
 from spyderplugins.widgets.pylintgui import PylintWidget, PYLINT_PATH
@@ -36,28 +30,43 @@ class PylintConfigPage(PluginConfigPage):
                                         'save_before', default=True)
         
         hist_group = QGroupBox(_("History"))
-        hist_label = QLabel(_("Pylint plugin results are stored here:\n"
-                              "%s\n\nThe following option "
-                              "will be applied at next startup.\n"
-                              ) % PylintWidget.DATAPATH)
-        hist_label.setTextInteractionFlags(Qt.TextSelectableByMouse)
-        hist_label.setWordWrap(True)
+        hist_label1 = QLabel(_("The following option will be applied at next "
+                               "startup."))
+        hist_label1.setWordWrap(True)
         hist_spin = self.create_spinbox(_("History: "),
                             _(" results"), 'max_entries', default=50,
                             min_=10, max_=1000000, step=10)
 
+        results_group = QGroupBox(_("Results"))
+        results_label1 = QLabel(_("Pylint plugin results are stored here:"))
+        results_label1.setWordWrap(True)
+
+        # Warning: do not try to regroup the following QLabel contents with 
+        # widgets above -- this string was isolated here in a single QLabel
+        # on purpose: to fix Issue 863
+        results_label2 = QLabel(PylintWidget.DATAPATH)
+
+        results_label2.setTextInteractionFlags(Qt.TextSelectableByMouse)
+        results_label2.setWordWrap(True)
+
         settings_layout = QVBoxLayout()
         settings_layout.addWidget(save_box)
         settings_group.setLayout(settings_layout)
 
         hist_layout = QVBoxLayout()
-        hist_layout.addWidget(hist_label)
+        hist_layout.addWidget(hist_label1)
         hist_layout.addWidget(hist_spin)
         hist_group.setLayout(hist_layout)
 
+        results_layout = QVBoxLayout()
+        results_layout.addWidget(results_label1)
+        results_layout.addWidget(results_label2)
+        results_group.setLayout(results_layout)
+
         vlayout = QVBoxLayout()
         vlayout.addWidget(settings_group)
         vlayout.addWidget(hist_group)
+        vlayout.addWidget(results_group)
         vlayout.addStretch(1)
         self.setLayout(vlayout)
 
@@ -99,7 +108,12 @@ class Pylint(PylintWidget, SpyderPluginMixin):
                                        triggered=self.change_history_depth)
         self.treewidget.common_actions += (None, history_action)
         return []
-    
+
+    def on_first_registration(self):
+        """Action to be performed on first plugin registration"""
+        self.main.tabify_plugins(self.main.inspector, self)
+        self.dockwidget.hide()
+
     def register_plugin(self):
         """Register plugin in Spyder's main window"""
         self.connect(self, SIGNAL("edit_goto(QString,int,QString)"),
@@ -116,7 +130,7 @@ class Pylint(PylintWidget, SpyderPluginMixin):
         
         self.main.source_menu_actions += [None, pylint_act]
         self.main.editor.pythonfile_dependent_actions += [pylint_act]
-                    
+
     def refresh_plugin(self):
         """Refresh pylint widget"""
         self.remove_obsolete_items()
